"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DispatcherClient = void 0;
const dispatcher_1 = require("../../protoc/dispatcher");
const hatchet_error_1 = __importDefault(require("../../util/errors/hatchet-error"));
const logger_1 = require("../../util/logger");
const retrier_1 = require("../../util/retrier");
const action_listener_1 = require("./action-listener");
class DispatcherClient {
    constructor(config, channel, factory) {
        this.config = config;
        this.client = factory.create(dispatcher_1.DispatcherDefinition, channel);
        this.logger = new logger_1.Logger(`Dispatcher`, config.log_level);
    }
    getActionListener(options) {
        return __awaiter(this, void 0, void 0, function* () {
            // Register the worker
            const registration = yield this.client.register(Object.assign({}, options));
            return new action_listener_1.ActionListener(this, registration.workerId);
        });
    }
    sendStepActionEvent(in_) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return (0, retrier_1.retrier)(() => __awaiter(this, void 0, void 0, function* () { return this.client.sendStepActionEvent(in_); }), this.logger);
            }
            catch (e) {
                throw new hatchet_error_1.default(e.message);
            }
        });
    }
    sendGroupKeyActionEvent(in_) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                return (0, retrier_1.retrier)(() => __awaiter(this, void 0, void 0, function* () { return this.client.sendGroupKeyActionEvent(in_); }), this.logger);
            }
            catch (e) {
                throw new hatchet_error_1.default(e.message);
            }
        });
    }
}
exports.DispatcherClient = DispatcherClient;
