import type { CallContext, CallOptions } from "nice-grpc-common";
import * as _m0 from "protobufjs/minimal";
export declare const protobufPackage = "";
export declare enum ActionType {
    START_STEP_RUN = 0,
    CANCEL_STEP_RUN = 1,
    START_GET_GROUP_KEY = 2,
    UNRECOGNIZED = -1
}
export declare function actionTypeFromJSON(object: any): ActionType;
export declare function actionTypeToJSON(object: ActionType): string;
export declare enum GroupKeyActionEventType {
    GROUP_KEY_EVENT_TYPE_UNKNOWN = 0,
    GROUP_KEY_EVENT_TYPE_STARTED = 1,
    GROUP_KEY_EVENT_TYPE_COMPLETED = 2,
    GROUP_KEY_EVENT_TYPE_FAILED = 3,
    UNRECOGNIZED = -1
}
export declare function groupKeyActionEventTypeFromJSON(object: any): GroupKeyActionEventType;
export declare function groupKeyActionEventTypeToJSON(object: GroupKeyActionEventType): string;
export declare enum StepActionEventType {
    STEP_EVENT_TYPE_UNKNOWN = 0,
    STEP_EVENT_TYPE_STARTED = 1,
    STEP_EVENT_TYPE_COMPLETED = 2,
    STEP_EVENT_TYPE_FAILED = 3,
    UNRECOGNIZED = -1
}
export declare function stepActionEventTypeFromJSON(object: any): StepActionEventType;
export declare function stepActionEventTypeToJSON(object: StepActionEventType): string;
export declare enum ResourceType {
    RESOURCE_TYPE_UNKNOWN = 0,
    RESOURCE_TYPE_STEP_RUN = 1,
    RESOURCE_TYPE_WORKFLOW_RUN = 2,
    UNRECOGNIZED = -1
}
export declare function resourceTypeFromJSON(object: any): ResourceType;
export declare function resourceTypeToJSON(object: ResourceType): string;
export declare enum ResourceEventType {
    RESOURCE_EVENT_TYPE_UNKNOWN = 0,
    RESOURCE_EVENT_TYPE_STARTED = 1,
    RESOURCE_EVENT_TYPE_COMPLETED = 2,
    RESOURCE_EVENT_TYPE_FAILED = 3,
    RESOURCE_EVENT_TYPE_CANCELLED = 4,
    RESOURCE_EVENT_TYPE_TIMED_OUT = 5,
    UNRECOGNIZED = -1
}
export declare function resourceEventTypeFromJSON(object: any): ResourceEventType;
export declare function resourceEventTypeToJSON(object: ResourceEventType): string;
export interface WorkerRegisterRequest {
    /** the name of the worker */
    workerName: string;
    /** a list of actions that this worker can run */
    actions: string[];
    /** (optional) the services for this worker */
    services: string[];
    /** (optional) the max number of runs this worker can handle */
    maxRuns?: number | undefined;
}
export interface WorkerRegisterResponse {
    /** the tenant id */
    tenantId: string;
    /** the id of the worker */
    workerId: string;
    /** the name of the worker */
    workerName: string;
}
export interface AssignedAction {
    /** the tenant id */
    tenantId: string;
    /** the workflow run id (optional) */
    workflowRunId: string;
    /** the get group key run id (optional) */
    getGroupKeyRunId: string;
    /** the job id */
    jobId: string;
    /** the job name */
    jobName: string;
    /** the job run id */
    jobRunId: string;
    /** the step id */
    stepId: string;
    /** the step run id */
    stepRunId: string;
    /** the action id */
    actionId: string;
    /** the action type */
    actionType: ActionType;
    /** the action payload */
    actionPayload: string;
}
export interface WorkerListenRequest {
    /** the id of the worker */
    workerId: string;
}
export interface WorkerUnsubscribeRequest {
    /** the id of the worker */
    workerId: string;
}
export interface WorkerUnsubscribeResponse {
    /** the tenant id to unsubscribe from */
    tenantId: string;
    /** the id of the worker */
    workerId: string;
}
export interface GroupKeyActionEvent {
    /** the id of the worker */
    workerId: string;
    /** the id of the job */
    workflowRunId: string;
    getGroupKeyRunId: string;
    /** the action id */
    actionId: string;
    eventTimestamp: Date | undefined;
    /** the step event type */
    eventType: GroupKeyActionEventType;
    /** the event payload */
    eventPayload: string;
}
export interface StepActionEvent {
    /** the id of the worker */
    workerId: string;
    /** the id of the job */
    jobId: string;
    /** the job run id */
    jobRunId: string;
    /** the id of the step */
    stepId: string;
    /** the step run id */
    stepRunId: string;
    /** the action id */
    actionId: string;
    eventTimestamp: Date | undefined;
    /** the step event type */
    eventType: StepActionEventType;
    /** the event payload */
    eventPayload: string;
}
export interface ActionEventResponse {
    /** the tenant id */
    tenantId: string;
    /** the id of the worker */
    workerId: string;
}
export interface SubscribeToWorkflowEventsRequest {
    /** the id of the workflow run */
    workflowRunId: string;
}
export interface WorkflowEvent {
    /** the id of the workflow run */
    workflowRunId: string;
    resourceType: ResourceType;
    eventType: ResourceEventType;
    resourceId: string;
    eventTimestamp: Date | undefined;
    /** the event payload */
    eventPayload: string;
    /**
     * whether this is the last event for the workflow run - server
     * will hang up the connection but clients might want to case
     */
    hangup: boolean;
}
export interface OverridesData {
    /** the step run id */
    stepRunId: string;
    /** the path of the data to set */
    path: string;
    /** the value to set */
    value: string;
    /** the filename of the caller */
    callerFilename: string;
}
export interface OverridesDataResponse {
}
export declare const WorkerRegisterRequest: {
    encode(message: WorkerRegisterRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): WorkerRegisterRequest;
    fromJSON(object: any): WorkerRegisterRequest;
    toJSON(message: WorkerRegisterRequest): unknown;
    create(base?: DeepPartial<WorkerRegisterRequest>): WorkerRegisterRequest;
    fromPartial(object: DeepPartial<WorkerRegisterRequest>): WorkerRegisterRequest;
};
export declare const WorkerRegisterResponse: {
    encode(message: WorkerRegisterResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): WorkerRegisterResponse;
    fromJSON(object: any): WorkerRegisterResponse;
    toJSON(message: WorkerRegisterResponse): unknown;
    create(base?: DeepPartial<WorkerRegisterResponse>): WorkerRegisterResponse;
    fromPartial(object: DeepPartial<WorkerRegisterResponse>): WorkerRegisterResponse;
};
export declare const AssignedAction: {
    encode(message: AssignedAction, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): AssignedAction;
    fromJSON(object: any): AssignedAction;
    toJSON(message: AssignedAction): unknown;
    create(base?: DeepPartial<AssignedAction>): AssignedAction;
    fromPartial(object: DeepPartial<AssignedAction>): AssignedAction;
};
export declare const WorkerListenRequest: {
    encode(message: WorkerListenRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): WorkerListenRequest;
    fromJSON(object: any): WorkerListenRequest;
    toJSON(message: WorkerListenRequest): unknown;
    create(base?: DeepPartial<WorkerListenRequest>): WorkerListenRequest;
    fromPartial(object: DeepPartial<WorkerListenRequest>): WorkerListenRequest;
};
export declare const WorkerUnsubscribeRequest: {
    encode(message: WorkerUnsubscribeRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): WorkerUnsubscribeRequest;
    fromJSON(object: any): WorkerUnsubscribeRequest;
    toJSON(message: WorkerUnsubscribeRequest): unknown;
    create(base?: DeepPartial<WorkerUnsubscribeRequest>): WorkerUnsubscribeRequest;
    fromPartial(object: DeepPartial<WorkerUnsubscribeRequest>): WorkerUnsubscribeRequest;
};
export declare const WorkerUnsubscribeResponse: {
    encode(message: WorkerUnsubscribeResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): WorkerUnsubscribeResponse;
    fromJSON(object: any): WorkerUnsubscribeResponse;
    toJSON(message: WorkerUnsubscribeResponse): unknown;
    create(base?: DeepPartial<WorkerUnsubscribeResponse>): WorkerUnsubscribeResponse;
    fromPartial(object: DeepPartial<WorkerUnsubscribeResponse>): WorkerUnsubscribeResponse;
};
export declare const GroupKeyActionEvent: {
    encode(message: GroupKeyActionEvent, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GroupKeyActionEvent;
    fromJSON(object: any): GroupKeyActionEvent;
    toJSON(message: GroupKeyActionEvent): unknown;
    create(base?: DeepPartial<GroupKeyActionEvent>): GroupKeyActionEvent;
    fromPartial(object: DeepPartial<GroupKeyActionEvent>): GroupKeyActionEvent;
};
export declare const StepActionEvent: {
    encode(message: StepActionEvent, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): StepActionEvent;
    fromJSON(object: any): StepActionEvent;
    toJSON(message: StepActionEvent): unknown;
    create(base?: DeepPartial<StepActionEvent>): StepActionEvent;
    fromPartial(object: DeepPartial<StepActionEvent>): StepActionEvent;
};
export declare const ActionEventResponse: {
    encode(message: ActionEventResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ActionEventResponse;
    fromJSON(object: any): ActionEventResponse;
    toJSON(message: ActionEventResponse): unknown;
    create(base?: DeepPartial<ActionEventResponse>): ActionEventResponse;
    fromPartial(object: DeepPartial<ActionEventResponse>): ActionEventResponse;
};
export declare const SubscribeToWorkflowEventsRequest: {
    encode(message: SubscribeToWorkflowEventsRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): SubscribeToWorkflowEventsRequest;
    fromJSON(object: any): SubscribeToWorkflowEventsRequest;
    toJSON(message: SubscribeToWorkflowEventsRequest): unknown;
    create(base?: DeepPartial<SubscribeToWorkflowEventsRequest>): SubscribeToWorkflowEventsRequest;
    fromPartial(object: DeepPartial<SubscribeToWorkflowEventsRequest>): SubscribeToWorkflowEventsRequest;
};
export declare const WorkflowEvent: {
    encode(message: WorkflowEvent, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): WorkflowEvent;
    fromJSON(object: any): WorkflowEvent;
    toJSON(message: WorkflowEvent): unknown;
    create(base?: DeepPartial<WorkflowEvent>): WorkflowEvent;
    fromPartial(object: DeepPartial<WorkflowEvent>): WorkflowEvent;
};
export declare const OverridesData: {
    encode(message: OverridesData, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): OverridesData;
    fromJSON(object: any): OverridesData;
    toJSON(message: OverridesData): unknown;
    create(base?: DeepPartial<OverridesData>): OverridesData;
    fromPartial(object: DeepPartial<OverridesData>): OverridesData;
};
export declare const OverridesDataResponse: {
    encode(_: OverridesDataResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): OverridesDataResponse;
    fromJSON(_: any): OverridesDataResponse;
    toJSON(_: OverridesDataResponse): unknown;
    create(base?: DeepPartial<OverridesDataResponse>): OverridesDataResponse;
    fromPartial(_: DeepPartial<OverridesDataResponse>): OverridesDataResponse;
};
export type DispatcherDefinition = typeof DispatcherDefinition;
export declare const DispatcherDefinition: {
    readonly name: "Dispatcher";
    readonly fullName: "Dispatcher";
    readonly methods: {
        readonly register: {
            readonly name: "Register";
            readonly requestType: {
                encode(message: WorkerRegisterRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): WorkerRegisterRequest;
                fromJSON(object: any): WorkerRegisterRequest;
                toJSON(message: WorkerRegisterRequest): unknown;
                create(base?: DeepPartial<WorkerRegisterRequest>): WorkerRegisterRequest;
                fromPartial(object: DeepPartial<WorkerRegisterRequest>): WorkerRegisterRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                encode(message: WorkerRegisterResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): WorkerRegisterResponse;
                fromJSON(object: any): WorkerRegisterResponse;
                toJSON(message: WorkerRegisterResponse): unknown;
                create(base?: DeepPartial<WorkerRegisterResponse>): WorkerRegisterResponse;
                fromPartial(object: DeepPartial<WorkerRegisterResponse>): WorkerRegisterResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly listen: {
            readonly name: "Listen";
            readonly requestType: {
                encode(message: WorkerListenRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): WorkerListenRequest;
                fromJSON(object: any): WorkerListenRequest;
                toJSON(message: WorkerListenRequest): unknown;
                create(base?: DeepPartial<WorkerListenRequest>): WorkerListenRequest;
                fromPartial(object: DeepPartial<WorkerListenRequest>): WorkerListenRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                encode(message: AssignedAction, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): AssignedAction;
                fromJSON(object: any): AssignedAction;
                toJSON(message: AssignedAction): unknown;
                create(base?: DeepPartial<AssignedAction>): AssignedAction;
                fromPartial(object: DeepPartial<AssignedAction>): AssignedAction;
            };
            readonly responseStream: true;
            readonly options: {};
        };
        readonly subscribeToWorkflowEvents: {
            readonly name: "SubscribeToWorkflowEvents";
            readonly requestType: {
                encode(message: SubscribeToWorkflowEventsRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): SubscribeToWorkflowEventsRequest;
                fromJSON(object: any): SubscribeToWorkflowEventsRequest;
                toJSON(message: SubscribeToWorkflowEventsRequest): unknown;
                create(base?: DeepPartial<SubscribeToWorkflowEventsRequest>): SubscribeToWorkflowEventsRequest;
                fromPartial(object: DeepPartial<SubscribeToWorkflowEventsRequest>): SubscribeToWorkflowEventsRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                encode(message: WorkflowEvent, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): WorkflowEvent;
                fromJSON(object: any): WorkflowEvent;
                toJSON(message: WorkflowEvent): unknown;
                create(base?: DeepPartial<WorkflowEvent>): WorkflowEvent;
                fromPartial(object: DeepPartial<WorkflowEvent>): WorkflowEvent;
            };
            readonly responseStream: true;
            readonly options: {};
        };
        readonly sendStepActionEvent: {
            readonly name: "SendStepActionEvent";
            readonly requestType: {
                encode(message: StepActionEvent, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): StepActionEvent;
                fromJSON(object: any): StepActionEvent;
                toJSON(message: StepActionEvent): unknown;
                create(base?: DeepPartial<StepActionEvent>): StepActionEvent;
                fromPartial(object: DeepPartial<StepActionEvent>): StepActionEvent;
            };
            readonly requestStream: false;
            readonly responseType: {
                encode(message: ActionEventResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): ActionEventResponse;
                fromJSON(object: any): ActionEventResponse;
                toJSON(message: ActionEventResponse): unknown;
                create(base?: DeepPartial<ActionEventResponse>): ActionEventResponse;
                fromPartial(object: DeepPartial<ActionEventResponse>): ActionEventResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly sendGroupKeyActionEvent: {
            readonly name: "SendGroupKeyActionEvent";
            readonly requestType: {
                encode(message: GroupKeyActionEvent, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): GroupKeyActionEvent;
                fromJSON(object: any): GroupKeyActionEvent;
                toJSON(message: GroupKeyActionEvent): unknown;
                create(base?: DeepPartial<GroupKeyActionEvent>): GroupKeyActionEvent;
                fromPartial(object: DeepPartial<GroupKeyActionEvent>): GroupKeyActionEvent;
            };
            readonly requestStream: false;
            readonly responseType: {
                encode(message: ActionEventResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): ActionEventResponse;
                fromJSON(object: any): ActionEventResponse;
                toJSON(message: ActionEventResponse): unknown;
                create(base?: DeepPartial<ActionEventResponse>): ActionEventResponse;
                fromPartial(object: DeepPartial<ActionEventResponse>): ActionEventResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly putOverridesData: {
            readonly name: "PutOverridesData";
            readonly requestType: {
                encode(message: OverridesData, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): OverridesData;
                fromJSON(object: any): OverridesData;
                toJSON(message: OverridesData): unknown;
                create(base?: DeepPartial<OverridesData>): OverridesData;
                fromPartial(object: DeepPartial<OverridesData>): OverridesData;
            };
            readonly requestStream: false;
            readonly responseType: {
                encode(_: OverridesDataResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): OverridesDataResponse;
                fromJSON(_: any): OverridesDataResponse;
                toJSON(_: OverridesDataResponse): unknown;
                create(base?: DeepPartial<OverridesDataResponse>): OverridesDataResponse;
                fromPartial(_: DeepPartial<OverridesDataResponse>): OverridesDataResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly unsubscribe: {
            readonly name: "Unsubscribe";
            readonly requestType: {
                encode(message: WorkerUnsubscribeRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): WorkerUnsubscribeRequest;
                fromJSON(object: any): WorkerUnsubscribeRequest;
                toJSON(message: WorkerUnsubscribeRequest): unknown;
                create(base?: DeepPartial<WorkerUnsubscribeRequest>): WorkerUnsubscribeRequest;
                fromPartial(object: DeepPartial<WorkerUnsubscribeRequest>): WorkerUnsubscribeRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                encode(message: WorkerUnsubscribeResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): WorkerUnsubscribeResponse;
                fromJSON(object: any): WorkerUnsubscribeResponse;
                toJSON(message: WorkerUnsubscribeResponse): unknown;
                create(base?: DeepPartial<WorkerUnsubscribeResponse>): WorkerUnsubscribeResponse;
                fromPartial(object: DeepPartial<WorkerUnsubscribeResponse>): WorkerUnsubscribeResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
    };
};
export interface DispatcherServiceImplementation<CallContextExt = {}> {
    register(request: WorkerRegisterRequest, context: CallContext & CallContextExt): Promise<DeepPartial<WorkerRegisterResponse>>;
    listen(request: WorkerListenRequest, context: CallContext & CallContextExt): ServerStreamingMethodResult<DeepPartial<AssignedAction>>;
    subscribeToWorkflowEvents(request: SubscribeToWorkflowEventsRequest, context: CallContext & CallContextExt): ServerStreamingMethodResult<DeepPartial<WorkflowEvent>>;
    sendStepActionEvent(request: StepActionEvent, context: CallContext & CallContextExt): Promise<DeepPartial<ActionEventResponse>>;
    sendGroupKeyActionEvent(request: GroupKeyActionEvent, context: CallContext & CallContextExt): Promise<DeepPartial<ActionEventResponse>>;
    putOverridesData(request: OverridesData, context: CallContext & CallContextExt): Promise<DeepPartial<OverridesDataResponse>>;
    unsubscribe(request: WorkerUnsubscribeRequest, context: CallContext & CallContextExt): Promise<DeepPartial<WorkerUnsubscribeResponse>>;
}
export interface DispatcherClient<CallOptionsExt = {}> {
    register(request: DeepPartial<WorkerRegisterRequest>, options?: CallOptions & CallOptionsExt): Promise<WorkerRegisterResponse>;
    listen(request: DeepPartial<WorkerListenRequest>, options?: CallOptions & CallOptionsExt): AsyncIterable<AssignedAction>;
    subscribeToWorkflowEvents(request: DeepPartial<SubscribeToWorkflowEventsRequest>, options?: CallOptions & CallOptionsExt): AsyncIterable<WorkflowEvent>;
    sendStepActionEvent(request: DeepPartial<StepActionEvent>, options?: CallOptions & CallOptionsExt): Promise<ActionEventResponse>;
    sendGroupKeyActionEvent(request: DeepPartial<GroupKeyActionEvent>, options?: CallOptions & CallOptionsExt): Promise<ActionEventResponse>;
    putOverridesData(request: DeepPartial<OverridesData>, options?: CallOptions & CallOptionsExt): Promise<OverridesDataResponse>;
    unsubscribe(request: DeepPartial<WorkerUnsubscribeRequest>, options?: CallOptions & CallOptionsExt): Promise<WorkerUnsubscribeResponse>;
}
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export type DeepPartial<T> = T extends Builtin ? T : T extends globalThis.Array<infer U> ? globalThis.Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export type ServerStreamingMethodResult<Response> = {
    [Symbol.asyncIterator](): AsyncIterator<Response, void>;
};
export {};
